@@ -15,7 +15,7 @@
 #include <obstack.h>
 #include <stdio.h>
 #include <malloc.h>
-#include <libsvm/svm.h>
+#include <svm.h>
 #include <stdlib.h>
 
 VALUE mSVM, cSVMProblem, cSVMParameter, cSVMModel;
